@@ -1,34 +1,37 @@
 from __future__ import annotations
-from collections import defaultdict
-from dataclasses import dataclass, field
+
 import itertools
 import logging
 import typing as t
+from collections import defaultdict
+from dataclasses import dataclass, field
 
-from piccolo.columns.operators import (
-    LessThan,
-    LessEqualThan,
-    GreaterThan,
-    GreaterEqualThan,
-    Equal,
-)
+import pydantic
 from piccolo.columns import Column, Where
-from piccolo.columns.column_types import Array, Varchar, Text
+from piccolo.columns.column_types import Array, Text, Varchar
+from piccolo.columns.operators import (
+    Equal,
+    GreaterEqualThan,
+    GreaterThan,
+    LessEqualThan,
+    LessThan,
+)
 from piccolo.columns.operators.comparison import ComparisonOperator
 from piccolo.query.methods.delete import Delete
 from piccolo.query.methods.select import Select
 from piccolo.table import Table
-import pydantic
+from piccolo.utils.encoding import dump_json
 from pydantic.error_wrappers import ValidationError
-from starlette.routing import Router, Route
-from starlette.responses import JSONResponse, Response
 from starlette.requests import Request
+from starlette.responses import JSONResponse, Response
+from starlette.routing import Route, Router
 
 from .exceptions import MalformedQuery
-from .serializers import create_pydantic_model, Config
-from .validators import apply_validators, Validators
+from .serializers import Config, create_pydantic_model
+from .validators import Validators, apply_validators
 
-if t.TYPE_CHECKING:
+if t.TYPE_CHECKING:  # pragma: no cover
+    from piccolo.columns import Selectable
     from piccolo.query.methods.count import Count
     from piccolo.query.methods.objects import Objects
     from starlette.datastructures import QueryParams
@@ -235,7 +238,9 @@ class PiccoloCRUD(Router):
 
         """
         readable = self.table.get_readable()
-        query = self.table.select().columns(self.table.id, readable)
+        query = self.table.select().columns(
+            self.table._meta.primary_key._meta.name, readable
+        )
 
         limit = request.query_params.get("limit")
         if limit is not None:
@@ -507,7 +512,10 @@ class PiccoloCRUD(Router):
                 self.table._get_related_readable(i)
                 for i in self.table._meta.foreign_key_columns
             ]
-            columns = self.table._meta.columns + readable_columns
+            columns: t.List[Selectable] = [
+                *self.table._meta.columns,
+                *readable_columns,
+            ]
             query = self.table.select(
                 *columns, exclude_secrets=self.exclude_secrets
             )
@@ -526,7 +534,9 @@ class PiccoloCRUD(Router):
             column = getattr(self.table, order_by.property_name)
             query = query.order_by(column, ascending=order_by.ascending)
         else:
-            query = query.order_by(self.table.id, ascending=False)
+            query = query.order_by(
+                self.table._meta.primary_key, ascending=False
+            )
 
         # Pagination
         page_size = split_params.page_size or self.page_size
@@ -577,8 +587,9 @@ class PiccoloCRUD(Router):
         try:
             row = self.table(**model.dict())
             response = await row.save().run()
+            json = dump_json(response)
             # Returns the id of the inserted row.
-            return JSONResponse(response, status_code=201)
+            return CustomJSONResponse(json, status_code=201)
         except ValueError:
             return Response("Unable to save the resource.", status_code=500)
 
@@ -612,7 +623,7 @@ class PiccoloCRUD(Router):
         """
         row = self.table(ignore_missing=True)
         row_dict = row.__dict__
-        del row_dict["id"]
+        row_dict.pop("id", None)
 
         return CustomJSONResponse(
             self.pydantic_model_optional(**row_dict).json()
@@ -632,7 +643,11 @@ class PiccoloCRUD(Router):
         if row_id is None:
             return Response("Missing ID parameter.", status_code=404)
 
-        if not await self.table.exists().where(self.table.id == row_id).run():
+        if (
+            not await self.table.exists()
+            .where(self.table._meta.primary_key == row_id)
+            .run()
+        ):
             return Response("The resource doesn't exist", status_code=404)
 
         if (type(row_id) is int) and row_id < 1:
@@ -661,19 +676,19 @@ class PiccoloCRUD(Router):
         params = dict(request.query_params)
         split_params: Params = self._split_params(params)
         try:
-            columns = self.table._meta.columns
+            columns: t.Sequence[Selectable] = self.table._meta.columns
             if split_params.include_readable:
                 readable_columns = [
                     self.table._get_related_readable(i)
                     for i in self.table._meta.foreign_key_columns
                 ]
-                columns = columns + readable_columns
+                columns = [*columns, *readable_columns]
 
             row = (
                 await self.table.select(
                     *columns, exclude_secrets=self.exclude_secrets
                 )
-                .where(self.table.id == row_id)
+                .where(self.table._meta.primary_key == row_id)
                 .first()
                 .run()
             )
@@ -708,7 +723,9 @@ class PiccoloCRUD(Router):
         }
 
         try:
-            await cls.update(values).where(cls.id == row_id).run()
+            await cls.update(values).where(
+                cls._meta.primary_key == row_id
+            ).run()
             return Response(status_code=204)
         except ValueError:
             return Response("Unable to save the resource.", status_code=500)
@@ -740,10 +757,12 @@ class PiccoloCRUD(Router):
             )
 
         try:
-            await cls.update(values).where(cls.id == row_id).run()
+            await cls.update(values).where(
+                cls._meta.primary_key == row_id
+            ).run()
             new_row = (
                 await cls.select(exclude_secrets=self.exclude_secrets)
-                .where(cls.id == row_id)
+                .where(cls._meta.primary_key == row_id)
                 .first()
                 .run()
             )
@@ -757,7 +776,9 @@ class PiccoloCRUD(Router):
         Deletes a single row.
         """
         try:
-            await self.table.delete().where(self.table.id == row_id).run()
+            await self.table.delete().where(
+                self.table._meta.primary_key == row_id
+            ).run()
             return Response("Deleted the resource.", status_code=204)
         except ValueError:
             return Response("Unable to delete the resource.", status_code=500)
